@@ -8,7 +8,7 @@ use utf8;
 use parent 'Class::Accessor';
 use List::Util qw(uniq);
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 Travel::Status::DE::DBRIS::Formation::Group->mk_ro_accessors(
 	qw(designation name train_no train_type description desc_short destination has_sectors model series start_percent end_percent)
@@ -267,6 +267,7 @@ my %ice_name = (
 	8019 => 'Düsseldorf',
 	8020 => 'Amsterdam',
 	8022 => 'Waldecker Land',
+	8026 => 'Christmas-Train',
 	8029 => 'Europa/Europe',
 	9006 => 'Martin Luther',
 	9009 => 'Cottbus/Chóśebuz',
@@ -287,7 +288,8 @@ my %ice_name = (
 	9457 => 'Bundesrepublik Deutschland',
 	9481 => 'Rheinland-Pfalz',
 	9485 => 'Karriere-ICE',
-	9488 => 'Würzburg'
+	9488 => 'Würzburg',
+	9499 => 'Matterhorn'
 );
 
 # }}}
